@@ -6,6 +6,7 @@ import os
 import shutil
 from pathlib import Path
 import psycopg2
+from psycopg2.extras import execute_values
 import sys
 from redmail import EmailSender
 
@@ -91,12 +92,12 @@ def delete_directory(directory: WorkingDir) -> bool:
     return True
 
 
-def __create_sql_query(table_name, data: Dict[str, Any]) -> str:
+def __create_sql_query(table_name, data: List[Dict[str, Any]]) -> str:
     """Metodo private, che crea una query sql del tipo 'INSERT INTO [table_name] (col1, col2, etc...) VALUES (%(col1)s, %(col2)s, etc..)
 
     Args:
         table_name (str): nome della tabella in cui inserire i dati
-        data (Dict[str,Any]): dizionario contenente i dati da inserire in tabella
+        data (List[Dict[str,Any]]): dizionario contenente i dati da inserire in tabella
 
     Returns:
         str: query
@@ -105,11 +106,8 @@ def __create_sql_query(table_name, data: Dict[str, Any]) -> str:
         raise ValueError(
             f"The name of the table must be a string, and {table_name} is a {type(table_name)}"
         )
-    columns_comma = ",".join(data.keys())
-    columns = f"({columns_comma})"
-    values_comma = ")s, %(".join(data.keys())
-    values = f"({values_comma})"
-    return f"INSERT INTO {table_name} {columns} VALUES (%{values}s)"
+    columns = ",".join(data[0].keys())
+    return f"INSERT INTO {table_name} ({columns}) VALUES %s"
 
 
 def insert_on_db(
@@ -119,7 +117,7 @@ def insert_on_db(
     port: str,
     database: str,
     table_name: str,
-    data: Dict[str, Any],
+    data: List[Dict[str, Any]],
     truncate = False
 ) -> bool:
     """Genera la connessione al db PGSQL specificato ed esegue la query
@@ -131,7 +129,8 @@ def insert_on_db(
         port (str): porta
         database (str): database
         table_name (str): nome della tabella in cui inserire i dati
-        data (Dict[str,Any]): dizionario contenente i dati da inserire in tabella
+        data (List[Dict[str,Any]]): lista di dizionari contenente i dati da inserire in tabella (un dizionario per riga)
+        truncate (bool): default a False, parametro opzionale per decidere se fare la truncate o no della tabella
 
     Returns:
         boolean: controllo per verificare se la scrittura è andata a buon fine o no
@@ -144,8 +143,9 @@ def insert_on_db(
         logging.info(f"Connected to {database} on {host}")
         cursor = connection.cursor()
         if truncate:
-            cursor.execute('TRUNCATE %s', (table_name,))
-        cursor.execute(__create_sql_query(table_name, data), data)
+            cursor.execute(f'TRUNCATE {table_name}')
+        values = [[value for value in row.values()] for row in data]
+        execute_values(cursor, __create_sql_query(table_name, data), values)
         connection.commit()
         logging.info(f"Queries executed")
     except Exception as error:
